==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/PERMITASSOCIATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PERMITASSOCIATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PERMITASSOCIATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTPERMITID"/>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PERMITASSOCIATIONID_Type", propOrder = {
    "equipmentpermitid",
    "assetid",
    "positionid",
    "systemid",
    "categoryid",
    "locationid",
    "profileid",
    "ppmid",
    "standardwo"
})
public class PERMITASSOCIATIONID_Type {

    @XmlElement(name = "EQUIPMENTPERMITID", required = true)
    protected EQUIPMENTPERMITID_Type equipmentpermitid;
    @XmlElement(name = "ASSETID")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "POSITIONID")
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "SYSTEMID")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "CATEGORYID")
    protected CATEGORYID categoryid;
    @XmlElement(name = "LOCATIONID")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "PROFILEID")
    protected OBJECT_Type profileid;
    @XmlElement(name = "PPMID")
    protected PPM_Type ppmid;
    @XmlElement(name = "STANDARDWO")
    protected STDWOID_Type standardwo;

    /**
     * Obtient la valeur de la propriété equipmentpermitid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTPERMITID_Type }
     *     
     */
    public EQUIPMENTPERMITID_Type getEQUIPMENTPERMITID() {
        return equipmentpermitid;
    }

    /**
     * Définit la valeur de la propriété equipmentpermitid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTPERMITID_Type }
     *     
     */
    public void setEQUIPMENTPERMITID(EQUIPMENTPERMITID_Type value) {
        this.equipmentpermitid = value;
    }

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété positionid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Définit la valeur de la propriété positionid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Obtient la valeur de la propriété systemid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Définit la valeur de la propriété systemid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété profileid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getPROFILEID() {
        return profileid;
    }

    /**
     * Définit la valeur de la propriété profileid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setPROFILEID(OBJECT_Type value) {
        this.profileid = value;
    }

    /**
     * Obtient la valeur de la propriété ppmid.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Définit la valeur de la propriété ppmid.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Obtient la valeur de la propriété standardwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Définit la valeur de la propriété standardwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/PERMITASSOCIATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PERMITASSOCIATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PERMITASSOCIATIONID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTPERMITID"/>
 *         <choice>
 *           <element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}PROFILEID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *         </choice>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PERMITASSOCIATIONID_Type", propOrder = {
    "equipmentpermitid",
    "assetid",
    "positionid",
    "systemid",
    "categoryid",
    "locationid",
    "profileid",
    "ppmid",
    "standardwo"
})
public class PERMITASSOCIATIONID_Type {

    @XmlElement(name = "EQUIPMENTPERMITID", required = true)
    protected EQUIPMENTPERMITID_Type equipmentpermitid;
    @XmlElement(name = "ASSETID")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "POSITIONID")
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "SYSTEMID")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "CATEGORYID")
    protected CATEGORYID categoryid;
    @XmlElement(name = "LOCATIONID")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "PROFILEID")
    protected OBJECT_Type profileid;
    @XmlElement(name = "PPMID")
    protected PPM_Type ppmid;
    @XmlElement(name = "STANDARDWO")
    protected STDWOID_Type standardwo;

    /**
     * Gets the value of the equipmentpermitid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTPERMITID_Type }
     *     
     */
    public EQUIPMENTPERMITID_Type getEQUIPMENTPERMITID() {
        return equipmentpermitid;
    }

    /**
     * Sets the value of the equipmentpermitid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTPERMITID_Type }
     *     
     */
    public void setEQUIPMENTPERMITID(EQUIPMENTPERMITID_Type value) {
        this.equipmentpermitid = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the positionid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Sets the value of the positionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Gets the value of the systemid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Sets the value of the systemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the profileid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getPROFILEID() {
        return profileid;
    }

    /**
     * Sets the value of the profileid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setPROFILEID(OBJECT_Type value) {
        this.profileid = value;
    }

    /**
     * Gets the value of the ppmid property.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Sets the value of the ppmid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Gets the value of the standardwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Sets the value of the standardwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

}
